==> tuia-advert-center-api-1.5.0-20180623.102320-32-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/promotetest/AdvertPromoteTestDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.promotetest;

import cn.com.duiba.tuia.core.api.dto.BaseDto;

/**测试落地页返回虚体参数
 * Created by jzl on 18/5/14.
 */
public class AdvertPromoteTestDto extends BaseDto {

    /** 广告ID **/
    private Long advertId;

    /** 测试落地页url **/
    private String promoteUrl;

    /** 测试落地页名称 **/
    private String promoteName;

    /** 匹配的素材ID集合 ,分割**/
    private String materialIds;

    /** 状态 0审核中 1审核通过 2审核拒绝 默认0**/
    private Integer status;

    /** 审核拒绝原因 **/
    private String rejectReason;

    /** 投放开始时间 **/
    private String startDateStr;

    /** 投放结束时间 **/
    private String endDateStr;

    /** 权重 流量占比 **/
    private Double weight;

    public String getPromoteName() {
        return promoteName;
    }

    public void setPromoteName(String promoteName) {
        this.promoteName = promoteName;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public String getMaterialIds() {
        return materialIds;
    }

    public void setMaterialIds(String materialIds) {
        this.materialIds = materialIds;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getRejectReason() {
        return rejectReason;
    }

    public void setRejectReason(String rejectReason) {
        this.rejectReason = rejectReason;
    }

    public String getStartDateStr() {
        return startDateStr;
    }

    public void setStartDateStr(String startDateStr) {
        this.startDateStr = startDateStr;
    }

    public String getEndDateStr() {
        return endDateStr;
    }

    public void setEndDateStr(String endDateStr) {
        this.endDateStr = endDateStr;
    }

    public Double getWeight() {
        return weight;
    }

    public void setWeight(Double weight) {
        this.weight = weight;
    }
}

==> tuia-advert-center-api-2.0.6-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/promotetest/AdvertPromoteTestDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.promotetest;

import cn.com.duiba.tuia.core.api.dto.BaseDto;

/**测试落地页返回虚体参数
 * Created by jzl on 18/5/14.
 */
public class AdvertPromoteTestDto extends BaseDto {

    private static final long serialVersionUID = 4495104563533960093L;
    /** 广告ID **/
    private Long advertId;

    /** 测试落地页url **/
    private String promoteUrl;

    /** 测试落地页名称 **/
    private String promoteName;

    /** 匹配的素材ID集合 ,分割**/
    private String materialIds;

    /** 状态 0审核中 1审核通过 2审核拒绝 默认0**/
    private Integer status;

    /** 审核拒绝原因 **/
    private String rejectReason;

    //落地页类型：0-A/BTest,1-新媒体投放链接
    private Integer urlType;

    /** 投放开始时间 **/
    private String startDateStr;

    /** 投放结束时间 **/
    private String endDateStr;

    /** 权重 流量占比 **/
    private Double weight;

    public String getPromoteName() {
        return promoteName;
    }

    public void setPromoteName(String promoteName) {
        this.promoteName = promoteName;
    }

    public Integer getUrlType() {
        return urlType;
    }

    public void setUrlType(Integer urlType) {
        this.urlType = urlType;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public String getMaterialIds() {
        return materialIds;
    }

    public void setMaterialIds(String materialIds) {
        this.materialIds = materialIds;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getRejectReason() {
        return rejectReason;
    }

    public void setRejectReason(String rejectReason) {
        this.rejectReason = rejectReason;
    }

    public String getStartDateStr() {
        return startDateStr;
    }

    public void setStartDateStr(String startDateStr) {
        this.startDateStr = startDateStr;
    }

    public String getEndDateStr() {
        return endDateStr;
    }

    public void setEndDateStr(String endDateStr) {
        this.endDateStr = endDateStr;
    }

    public Double getWeight() {
        return weight;
    }

    public void setWeight(Double weight) {
        this.weight = weight;
    }
}
